##----------------------------------------------------------------------------##
##=Purpose: Exercise 1.2 of Beyond Classic Designs & Analysis for Health      ##
##          Data in Singapore (27 June to 8 July 2022)                        ##
##
##=Data required: 
##  - Ex 1.2 chlordecone.xls
##  - alcohol_lungcancer_smoking.dta
##
##=R packages/libraries required:
##  - Epi 
##    * twoby2: For generating both RR and OR, esp RR as fisher.test can be 
##              used to get OR and its 95%CI.
##  - epiDisplay: 
##    * mhor: Provides Mantel-Haenszel OR and the subgroups ORs
##    Note: - mantelhaen.test function generates Mantel-Haenszel OR
##          - EpiStats library has CCInter provides detailed information, such,
##            Mantel-Haenszel OR and the subgroups ORs, and crude OR too.
##          - epiR library has epi.2by2 provides crude and Mantel-Haenszel 
##            adjusted measures of association and chi-squared tests of 
##            homogeneity
##  - haven:
##    * read_dta: To read in recent versions of STATA dta files.
##  - readxl:
##    * read_excel:  
##
##=Created by:
##  - Francesca Graziano 
##  - Zilu Feng
##  - Zihan 
##  - Chuen Seng Tan
##  - Marie Reilly
##
##=Changes (if any):
##  -DDMMYYYY: Describe
##
##----------------------------------------------------------------------------##

##-Set the working directory to the data folder where the datasets are saved:
setwd("D:/nbox/Education/Marie_short_course/Singapore course 2022/20220602/exercises/data")

##-R libraries to install:
#install.packages(c("Epi","epiDisplay","haven","readxl"))
##-Load the R libraries
library(Epi)
library(epiDisplay)
library(haven)
library(readxl)

## Alternative approach by writing R function to calculate OR
CALC_OR <- function(a,b,c,d) {
  #create an empty object named "Q1_TAB". Info will be added to it
  Q1_TAB <- NULL
  #make "Q1_TAB" a 2 by 2 table
  #"byrow = T"is required as default is to fill by columns
  Q1_TAB <- matrix(c(a, b, c, d), nrow = 2, ncol = 2, byrow = T) 
  #fill in names
  rownames(Q1_TAB) <- c("Exposed", "unExposed")
  colnames(Q1_TAB) <- c("Disease", "noDisease")
  #displays the newly created table on screen
  print(Q1_TAB)
  #calculate odds ratio
  ODDS_RATIO <- round((a/b) / (c/d), 3)
  #calculate 95% CI of odds ratio
  SE_LOG_OR <- sqrt( (1/a) + (1/b) + (1/c) + (1/d))
  CI_UP_LOG_OR = log(ODDS_RATIO) + 1.96*SE_LOG_OR
  CI_LOW_LOG_OR = log(ODDS_RATIO) - 1.96*SE_LOG_OR
  CI_UPPER_OR = round(exp(CI_UP_LOG_OR),3)
  CI_LOWER_OR = round(exp(CI_LOW_LOG_OR),3)
  print(paste("Odds ratio =", ODDS_RATIO, "(", CI_LOWER_OR, ",", CI_UPPER_OR, ")"), sep = '')
}

## Alternative approach by writing R function to calculate RR
CALC_RR <- function(a,b,c,d) {
  #create an empty object named "Q1_TAB". Info will be added to it
  Q1_TAB <- NULL
  #make "Q1_TAB" a 2 by 2 table
  #"byrow = T"is required as default is to fill by columns
  Q1_TAB <- matrix(c(a, b, c, d), nrow = 2, ncol = 2, byrow = T) 
  #fill in names
  rownames(Q1_TAB) <- c("Exposed", "unExposed")
  colnames(Q1_TAB) <- c("Disease", "noDisease")
  #displays the newly created table on screen
  print(Q1_TAB)
  #calculate risk ratio
  RISK_RATIO <- round((a/(a+b)) / (c/(c+d)), 3)
  #calculate 95% CI of risk ratio
  SE_LOG_RR <- sqrt( (1/a) - (1/(a+b)) + 
                       (1/c) - (1/(c+d)))
  CI_UP_LOG_RR = log(RISK_RATIO) + 1.96*SE_LOG_RR
  CI_LOW_LOG_RR = log(RISK_RATIO) - 1.96*SE_LOG_RR
  CI_UPPER_RR = round(exp(CI_UP_LOG_RR),3)
  CI_LOWER_RR = round(exp(CI_LOW_LOG_RR),3)
  print(paste("Risk ratio =", RISK_RATIO, "(", CI_LOWER_RR, ",", CI_UPPER_RR, ")"), sep = '')
  
}

################################################################################
##                               Question 1      
##
##-1.	Reproduce the RR (with 95% C.I.) in Example 2.1 (on page 6 of CES 2.1-2.2)
##    and the OR (with 95% CI) using the on-line calculator at Openepi.com or 
##    direct/immediate commands in statistical software (such as the immediate 
##    commands in Stata).
################################################################################c
#1- create a contingency table
M1 <- matrix(c(230 , 106, 4885  , 4779 ),nrow = 2, ncol = 2)
rownames(M1) <- c("exposed", "unexposed")
colnames(M1) <- c("Outcome Yes", "Outcome No")
M1

## 2- compute the RR (with 95% CI) and OR (with 95% CI) 
Epi::twoby2(M1)

## Alternative approach by writing R function to calculate OR
CALC_OR(230, 4885, 106, 4779)

## Alternative approach by writing R function to calculate RR
CALC_RR(230, 4885, 106, 4779)


################################################################################
##                               Question 2 (i)    
##
##-(i) Using the following three tables from Example 2.3 (page 16, CES 2.3-2.5), 
##     find the crude OR, the three separate ORs, and the Mantel-Haenszel OR. 
##
##    [see exercise for the table]
##
################################################################################

#1- create the contingency table by Age as an array
M2 <- array(c(1, 28, 32, 1553,
              4, 47, 74, 1221,
              7, 29, 69, 440),
            dim = c(2, 2, 3),
            dimnames = list(
              CHD = c("yes CHD", "no CHD"),
              Diabetes = c("Yes", "No"),
              Age = c("42-51", "52-61", "62-71")))
M2

#2- compute the OR (with 95% CI) by age group, MH-OR and crude OR
#OR by age group and MH-OR
epiDisplay::mhor(mhtable=M2, graph = F)

#Breslow Day test
DescTools::BreslowDayTest(M2)

#Crude OR
Mcrude <- matrix(M2[1:4]+M2[5:8]+M2[9:12],nrow = 2, ncol = 2)
rownames(Mcrude) <- c("yes CHD", "no CHD")
colnames(Mcrude) <- c("Yes", "No")
fisher.test(Mcrude)


################################################################################
##                               Question 3    
##
##-3. The following table is taken from Table 4 of "Chlordecone exposure, 
##    length of gestation and risk of preterm birth" by Kadhel et al, 
##    American Journal of Epidemiology,  2014 Mar 1;179(5):536-44. 
##    doi: 10.1093/aje/kwt313.PMID: 24401561 
##
##    [see exercise for the table]
##
##    These summary data are provided in the Excel sheet Ex 1.2 chlordecone.xls, 
##    which has 4 columns (category: 1,2,3,4,5; level as above; 
##    preterm 1 (preterm) ,0 (non-preterm; count). 
##    The summary data can be used by any command that allows you to specify a 
##    frequency option (e.g. fweights in Stata) or you can modify the data to 
##    have a record for each individual (e.g. using the "expand" command in 
##    Stata)                                                                                
################################################################################

################################################################################
##                               Question 3 (i)    
##
##-(i) Conduct a Chi-squared test of the association between chlordecone level 
##     and preterm birth.
################################################################################

#1- import data using read_excel function 
Cl_decone <- readxl::read_excel("Ex 1.2 chlordecone.xls")
Cl_decone

#2-	conduct a Chi-squared test of the association between chlordecone level and preterm birth.
colnames(Cl_decone)
chisq.test(cbind(Cl_decone$count[1:5],Cl_decone$count[6:10]))


################################################################################
##                               Question 3 (ii)    
##
##-(ii)	Test for evidence of a trend for increasing risk with increasing 
##      exposure, using the category numbers (1 to 5) as scores. The test for 
##      trend may provide the separate ORs in the categories, in which case you 
##      will note that all except one are non-significant, yet the trend you 
##      found is borderline significant. 
################################################################################

#1- Generate the trend test and the separate ORs
#Trend test
prop.trend.test(Cl_decone$count[1:5],Cl_decone$count[1:5]+Cl_decone$count[6:10])

#2- separate OR: Cat 1 vs 2
fisher.test(cbind(Cl_decone$count[c(2,1)],Cl_decone$count[c(7,6)]))
#3- separate OR: Cat 1 vs 3
fisher.test(cbind(Cl_decone$count[c(3,1)],Cl_decone$count[c(8,6)]))
#4- separate OR: Cat 1 vs 4
fisher.test(cbind(Cl_decone$count[c(4,1)],Cl_decone$count[c(9,6)]))
#5- separate OR: Cat 1 vs 5
fisher.test(cbind(Cl_decone$count[c(5,1)],Cl_decone$count[c(10,6)]))


################################################################################
##                               Question 4    
##
##-4. Table 2.3 in Chapter 2 (page 12, CES 2.3-2.5) presents the following data 
##    on alcohol intake and lung cancer.
##
##    [see exercise for the data]
################################################################################


################################################################################
##                               Question 4 (i)    
##
##-(i)	Test for a trend in risk with alcohol level using simple categories 
##      and/or scores for alcohol intake. 
################################################################################

#1- create a contingency table
A<-matrix(c(1090,806,  378, 679, 3976,2244,783 ,1166) , ncol = 2)
colnames(A) <- c("Lung Cancer" , "No Lung Cancer")
rownames(A) <- c("<1", "1-3.9","4-6.9","7+")
A


#2- performs chi-squared test for trend in proportion 
#Simple category:
prop.trend.test(A[,1],A[,1]+A[,2])
#Simple score:
prop.trend.test(A[,1],A[,1]+A[,2],score=c(0.5,2.5,5.5,7))


################################################################################
##                               Question 4 (ii)    
##
##-(ii)	Table 2.4 in Chapter 2 (also on page 12, CES 2.3-2.5) includes the 
##      following information:
##
##      [see exercise for the information]
##
##      Use the appropriate four numbers from this information in OpenEpi or a 
##      statistical package to calculate the OR for the association between 
##      smoking and lung cancer. 
##       
##      Would you expect this association to be confounded by drinking? 
##      Why/why not?
################################################################################

#1- crude OR 
#Create the data with the relevant 4 numbers:
dat1<-cbind(c(1488,1465),c(1256,6913))
rownames(dat1)<-c("Yes Smoker","No Smoker")
colnames(dat1)<-c("Yes","No")

fisher.test(dat1)

#2- MH-OR 
#Create 3-dimensional array
M2 <- array(c(786,271,665,1284,
              702,1194,591,5629),
            dim = c(2, 2, 2),
            dimnames = list(
              Smoker = c("Yes Smoker","No Smoker"),
              Lung.Cancer = c("Yes", "No"),
              Alcohol = c("Heavy Drinker", "Light Drinker")))
M2

epiDisplay::mhor(mhtable=M2, graph = F)


################################################################################
##                               Question 4 (iii)    
##
##-(iii) These data are available as "alcohol_lungcancer_smoking.dta". Open the 
##       dataset, display the table in (i) above and request the test of trend.
################################################################################

#1- import dataset
alcohol_lungcancer_smoking <- read_dta("alcohol_lungcancer_smoking.dta")

#2- create a contingency table 
tab1<-table(alcohol_lungcancer_smoking$alcohol,alcohol_lungcancer_smoking$case)
#case: 1 (No) and 2 (Yes)
#alcohol: 1 (<1), 2 (1-3.9), 3 (4-6.9) and 4 (7+)
tab1

#3- test of trend 
#Simple category:
prop.trend.test(tab1[,2],tab1[,1]+tab1[,2])
#Simple score:
prop.trend.test(tab1[,2],tab1[,1]+tab1[,2],score=c(0.5,2.5,5.5,7))


################################################################################
##                               Question 4 (iv)    
##
##-(iv)	For the same data, find the OR for the association between smoking and 
##      lung cancer. Check if it is confounded by alcohol and compare to your 
##      expectation in (ii)
################################################################################

#1- create a contingency table 
cont_table <- table(smoker = alcohol_lungcancer_smoking$smoker,
                    lungCancer= alcohol_lungcancer_smoking$case, 
                    alcol = alcohol_lungcancer_smoking$alcohol_bin)
cont_table

#2- get MH-OR and the OR for each stratum
#OR by alcohol group and MH-OR
epiDisplay::mhor(mhtable=cont_table, graph = F)

#3- crude OR
fisher.test(table(alcohol_lungcancer_smoking$smoker,
                  alcohol_lungcancer_smoking$case))
