//----------------------------------------------------------------------------//
//=Purpose: Exercise 1.2 of Beyond Classic Designs & Analysis for Health      //
//          Data in Singapore (27 June to 8 July 2022)                        //
//
//=Data required: 
//  - Ex 1.2 chlordecone.xls
//  - alcohol_lungcancer_smoking.dta
//
//=Stata packages/libraries required:
//  - None
//
//=Created by:
//  - Zihan 
//  - Francesca Graziano 
//  - Zilu Feng
//  - Chuen Seng Tan
//  - Marie Reilly
//
//=Changes (if any):
//  -DDMMYYYY: Describe
//
//----------------------------------------------------------------------------//

//-Set the working directory to the data folder where the datasets are saved:
cd "D:/nbox/Education/Marie_short_course/Singapore course 2022/20220602/exercises/data"

////////////////////////////////////////////////////////////////////////////////
//                               Question 1      
//
//-1.Reproduce the RR (with 95% C.I.) in Example 2.1 (on page 6 of CES 2.1-2.2)
//    and the OR (with 95% CI) using the on-line calculator at Openepi.com or 
//    direct/immediate commands in statistical software (such as the immediate 
//    commands in Stata).
////////////////////////////////////////////////////////////////////////////////

*RR:
csi 230 106 4885 4779

*OR:
cci 230 106 4885 4779


////////////////////////////////////////////////////////////////////////////////
//                               Question 2 (i)    
//
//-(i) Using the following three tables from Example 2.3 (page 16, CES 2.3-2.5), 
//     find the crude OR, the three separate ORs, and the Mantel-Haenszel OR. 
//
//    [see exercise for the table]
//
////////////////////////////////////////////////////////////////////////////////

*For M-H OR, you should use *expand* command to expand the tables to individual dataset or use "fw=" option in *cc* command:

clear all
input agecat chd diabetes count
1 1 1 1
1 1 0 32
1 0 1 28
1 0 0 1553
2 1 1 4
2 1 0 74
2 0 1 47
2 0 0 1221
3 1 1 7
3 1 0 69
3 0 1 29
3 0 0 440
end

expand count 
drop count

cc chd diabetes, by(agecat) woolf bd

*Alternatively:

clear all
input agecat chd diabetes count
1 1 1 1
1 1 0 32
1 0 1 28
1 0 0 1553
2 1 1 4
2 1 0 74
2 0 1 47
2 0 0 1221
3 1 1 7
3 1 0 69
3 0 1 29
3 0 0 440
end

cc chd diabetes [fw=count], by(agecat) woolf bd


////////////////////////////////////////////////////////////////////////////////
//                               Question 3    
//
//-3. The following table is taken from Table 4 of "Chlordecone exposure, 
//    length of gestation and risk of preterm birth" by Kadhel et al, 
//    American Journal of Epidemiology,  2014 Mar 1;179(5):536-44. 
//    doi: 10.1093/aje/kwt313.PMID: 24401561 
//
//    [see exercise for the table]
//
//    These summary data are provided in the Excel sheet Ex 1.2 chlordecone.xls, 
//    which has 4 columns (category: 1,2,3,4,5; level as above; 
//    preterm 1 (preterm) ,0 (non-preterm; count). 
//    The summary data can be used by any command that allows you to specify a 
//    frequency option (e.g. fweights in Stata) or you can modify the data to 
//    have a record for each individual (e.g. using the "expand" command in 
//    Stata)                                                                                
////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////
//                               Question 3 (i)    
//
//-(i) Conduct a Chi-squared test of the association between chlordecone level 
//     and preterm birth.
////////////////////////////////////////////////////////////////////////////////

*First input the data: 

import excel "Ex 1.2 chlordecone.xls", sheet("Sheet1") firstrow clear

label define chlorlbl 1 "<0.14" 2 "0.14-0.28" 3 "0.29-0.51" 4 "0.52-0.97" 5 ">=0.98" 
label values category chlorlbl

*then expand the data to have one record for each individual as follows:

expand count 
drop count

*do the Chi-squared test for association and this provides the output:

tab category preterm, chi2


////////////////////////////////////////////////////////////////////////////////
//                               Question 3 (ii)    
//
//-(ii)Test for evidence of a trend for increasing risk with increasing 
//      exposure, using the category numbers (1 to 5) as scores. The test for 
//      trend may provide the separate ORs in the categories, in which case you 
//      will note that all except one are non-significant, yet the trend you 
//      found is borderline significant. 
////////////////////////////////////////////////////////////////////////////////
*Test for trend and provide separate ORs in the categories:

tabodds preterm score, or






////////////////////////////////////////////////////////////////////////////////
//                               Question 4    
//
//-4. Table 2.3 in Chapter 2 (page 12, CES 2.3-2.5) presents the following data 
//    on alcohol intake and lung cancer.
//
//    [see exercise for the data]
////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////
//                               Question 4 (i)    
//
//-(i)Test for a trend in risk with alcohol level using simple categories 
//      and/or scores for alcohol intake. 
////////////////////////////////////////////////////////////////////////////////

*Input data using simple categories and scores and expand to individual records:

clear all
input alcohol_c alcohol_s LC count
1 0.5 1 1090
2 2.5 1 806
3 5.5 1 378
4 7.0 1 679
1 0.5 0 3976
2 2.5 0 2244
3 5.5 0 783
4 7.0 0 1166
end

expand count 
drop count

*Test for trend and provide separate ORs in the categories:

tabodds LC alcohol_c, or
    tabodds LC alcohol_s, or


////////////////////////////////////////////////////////////////////////////////
//                               Question 4 (ii)    
//
//-(ii)Table 2.4 in Chapter 2 (also on page 12, CES 2.3-2.5) includes the 
//      following information:
//
//      [see exercise for the information]
//
//      Use the appropriate four numbers from this information in OpenEpi or a 
//      statistical package to calculate the OR for the association between 
//      smoking and lung cancer. 
//       
//      Would you expect this association to be confounded by drinking? 
//      Why/why not?
////////////////////////////////////////////////////////////////////////////////

*Input data in appropriate order to get crude OR:

cci 1488 1465 1256 6913

*Input data in appropriate order to get MH-OR:

clear all
input drinker LC smoking count
1 1 1 786
1 1 0 271
1 0 1 665
1 0 0 1284
2 1 1 702
2 1 0 1194
2 0 1 591
2 0 0 5629
end

*calculate crude and M-H OR:

cc LC smoking [fw=count], by(drinker) woolf


////////////////////////////////////////////////////////////////////////////////
//                               Question 4 (iii)    
//
//-(iii) These data are available as "alcohol_lungcancer_smoking.dta". Open the 
//       dataset, display the table in (i) above and request the test of trend.
////////////////////////////////////////////////////////////////////////////////

*Load the dataset:

use alcohol_lungcancer_smoking.dta, clear

*re-code variable "case" and re-label it:
recode case (1=0) (2=1)
label define caselbl 0 "no" 1 "yes"
label values case caselbl


*test for trend with simple categories:

tabodds case alcohol

*Generating a new variable alcohol_s:

codebook alcohol
gen alcohol_s= 0.5    if alcohol==1
replace alcohol_s=2.5 if alcohol==2
replace alcohol_s=5.5 if alcohol==3
replace alcohol_s=7   if alcohol==4

*test for trend with simple scores:

tabodds case alcohol_s


////////////////////////////////////////////////////////////////////////////////
//                               Question 4 (iv)    
//
//-(iv)For the same data, find the OR for the association between smoking and 
//      lung cancer. Check if it is confounded by alcohol and compare to your 
//      expectation in (ii)
////////////////////////////////////////////////////////////////////////////////

*Calculate OR regarding smoking and lung cancer:

cc case smoker, by(alcohol_bin) woolf
